@@ -8,7 +8,8 @@ from database2text.tool import *
 class mysql(object):
     def ana_TABLE(otype):
         for oname, in db.exec("show tables"):
-            _,odata=db.res1("show create table %s" %(oname))
+            res=db.res1("show create table %s" %(oname))
+            odata=res[1]
             oridata=[]
             coldata=[]
             tdesc=db.res1("SELECT TABLE_COMMENT FROM INFORMATION_SCHEMA.TABLES  WHERE TABLE_NAME ='%s' AND TABLE_SCHEMA = '%s'" %(oname,database))
