@@ -15,6 +15,8 @@ class oracle(object):
             oridata=[]
             for col in db.exec2("select * from all_tab_cols where owner='%s' and table_name='%s' order by column_id" %(owner,oname)):
                 col["COLUMN_COMMENT"]=db.res1("select comments from user_col_comments where table_name=:n and column_name=:cn",n=oname,cn=col["COLUMN_NAME"])
+                if col["DATA_DEFAULT"]!=None:
+                    col["DATA_DEFAULT"]=col["DATA_DEFAULT"].strip()
                 oridata.append(col)
             for column_name,data_type,char_length,data_precision,data_scale,nullable,default_length,data_default in db.exec("select column_name,data_type,char_length,data_precision,data_scale,nullable,default_length,data_default from all_tab_cols where owner='%s' and table_name='%s' order by column_id" %(owner,oname)):
                 odata=odata+"  %s%*s" %(column_name,maxcsize-len(column_name)+1," ")
@@ -41,15 +43,18 @@ class oracle(object):
                         print("table %s column %s type %s length %s %s %s" %(oname,column_name,data_type,char_length,data_precision,data_scale))
                         sys.exit(-1)
                     cns=column_name
-                elif data_type in ("VARCHAR2","VARCHAR","CHAR"):
+                elif data_type in ("VARCHAR2","VARCHAR","CHAR","NVARCHAR2","NVARCHAR"):
                     if char_length==1:cns=column_name
                     odata=odata+"%s(%d)" %(data_type,char_length)
                 elif data_type.startswith("TIMESTAMP"):
                     cns="%s[20]" %(column_name)
                     odata=odata+"%s" %(data_type)
-                elif data_type in("DATE","BLOB"):
+                elif data_type in("DATE"):
                     cns="%s[20]" %(column_name)
                     odata=odata+"%s" %(data_type)
+                elif data_type in("CLOB","BLOB","NCLOB"):
+                    cns="%s[2000]" %(column_name)
+                    odata=odata+"%s" %(data_type)
                 elif data_type in ("FLOAT"):
                     ctype="double"
                     odata=odata+"FLOAT(%d)" %(data_precision)
